@@ -13,7 +13,8 @@ lmrob <-
 	    lmrob.control(...) else lmrob.control(method = method, ...)
     else if (length(list(...))) ## "sophisticated version" of chk.s(...)
 	warning("arguments .. in ",
-		sub(")$", "", sub("^list\\(", "", deparse(list(...), control = c()))), "  are disregarded.\n",
+		sub(")$", "", sub("^list\\(", "", deparse(list(...), control = c()))),
+		"  are disregarded.\n",
 		"  Maybe use  lmrob(*, control=lmrob.control(....) with all these.")
     ret.x <- x
     ret.y <- y
@@ -36,7 +37,7 @@ lmrob <-
 	stop(gettextf("number of offsets is %d, should equal %d (number of observations)",
 		      length(offset), NROW(y)), domain = NA)
     if (!miss.ctrl && !missing(method) && method != control$method) {
-	warning("Methods argument set by method is different from method in control\n",
+	warning("The 'method' argument is different from 'control$method'\n",
 		"Using the former, method = ", method)
 	control$method <- method
     }
@@ -155,6 +156,7 @@ lmrob <-
 		    control$cov <- ".vcov.w"
 	    }
 	    z <- lmrob.fit(x, y, control, init=init, mf = mf) #-> ./lmrob.MM.R
+	    ##   ---------
             if(is.character(ini) && !grepl(paste0("^", ini), control$method))
                 control$method <- paste0(ini, control$method)
 	    if (singular.fit) {
@@ -190,10 +192,11 @@ lmrob <-
 	    z$residuals <- z$residuals/wts
 	    z$fitted.values <- save.y - z$residuals
 	    z$weights <- w
-	    if (zero.weights) {
+	    if (zero.weights) { # compute residuals, fitted, wts...  also for the 0-weight obs
                 coef <- z$coefficients
 		coef[is.na(coef)] <- 0
 		f0 <- x0 %*% coef
+                ## above  ok := (w != 0);  nok := (w == 0)
 		if (ny > 1) {
 		    save.r[ok, ] <- z$residuals
 		    save.r[nok, ] <- y0 - f0
@@ -610,14 +613,15 @@ variable.names.lmrob <- function(object, full = FALSE, ...)
     else character()
 }
 
-vcov.lmrob <- function (object, cov = object$control$cov, ...) {
-    if (!is.null(object$cov) && (missing(cov) ||
-				 identical(cov, object$control$cov)))
-	object$cov
+vcov.lmrob <- function (object, cov = object$control$cov, complete = TRUE, ...) {
+    if(!is.null(object$cov) && (missing(cov) ||
+				identical(cov, object$control$cov)))
+	.vcov.aliased(aliased = is.na(coef(object)), object$cov,
+		      complete= if(is.na(complete)) FALSE else complete)
     else {
 	## cov is typically = ".vcov.w" or ".vcov.avar1", but can be *any* user func.
 	lf.cov <- if (!is.function(cov)) get(cov, mode = "function") else cov
-	lf.cov(object, ...)
+	lf.cov(object, complete=complete, ...)
     }
 }
 
