@@ -24,7 +24,7 @@ m_s_subsample <- function(x1, x2, y, control, orthogonalize=TRUE) {
             b1=double(NCOL(x1)),
             b2=double(NCOL(x2)),
             tuning_chi=as.double(control$tuning.chi),
-            ipsi=robustbase:::.psi2ipsi(control$psi),
+            ipsi=.psi2ipsi(control$psi),
             bb=as.double(control$bb),
             K_m_s=as.integer(control$k.m_s),
             max_k=as.integer(control$k.max),
@@ -60,7 +60,7 @@ m_s_descent <- function(x1, x2, y, control, b1, b2, scale) {
             b1=as.double(b1),
             b2=as.double(b2),
             tuning_chi=as.double(control$tuning.chi),
-            ipsi=robustbase:::.psi2ipsi(control$psi),
+            ipsi=.psi2ipsi(control$psi),
             bb=as.double(control$bb),
             K_m_s=as.integer(control$k.m_s),
             max_k=as.integer(control$k.max),
@@ -89,7 +89,7 @@ find_scale <- function(r, s0, n, p, control) {
             scale = as.double(s0),
             coefficients = double(p),
             as.double(c.chi),
-            robustbase:::.psi2ipsi(control$psi),
+            .psi2ipsi(control$psi),
             as.double(control$bb),
             best_r = 0L,
             groups = 0L,
